Keyboard shortcuts

Press or to navigate between chapters

Press S or / to search in the book

Press ? to show this help

Press Esc to hide this help

Operators Reference

This is a compact reference for the operators described in the language chapters.

Arithmetic

OperatorMeaning
+Addition
-Subtraction
*Multiplication
/Division
%Modulo
**Exponentiation

Comparison

OperatorMeaning
<Less than
>Greater than
<=Less than or equal
>=Greater than or equal
==Equal
!=Not equal

Logical / Bitwise

OperatorMeaning
AndBitwise AND
OrBitwise OR
XorBitwise XOR

Unary

OperatorMeaning
-Negation
+Unary plus, a no-op
++Postfix increment
--Postfix decrement

See Operators, Unary Operators, Comparisons, and Logical Operators for the full discussion and caveats.


← Previous Next →